from op5helpers import *

nacoma_api_endpoint = 'https://'+os.environ.get("MONITOR_SERVER",'localhost')+'/api/config/'
authed_user = ('monitor', 'monitor')

def test_proper_uri_adapts_to_format():
    r = requests.get(nacoma_api_endpoint+'host?format=html', auth=authed_user, verify=False)
    eq_(r.headers['content-type'], 'text/html; charset=utf-8')
    eq_(r.status_code, 200)

    r = requests.get(nacoma_api_endpoint+'host?format=xml', auth=authed_user, verify=False)
    eq_(r.headers['content-type'], 'application/xml; charset=utf-8')
    eq_(r.status_code, 200)

    r = requests.get(nacoma_api_endpoint+'host?format=json', auth=authed_user, verify=False)
    eq_(r.headers['content-type'], 'application/json; charset=utf-8')
    eq_(r.status_code, 200)

def test_inproper_uri_adapts_to_format():
    r = requests.get(nacoma_api_endpoint+'non_existing_ztuffs_here11?format=html', auth=authed_user, verify=False)
    eq_(r.headers['content-type'], 'text/html; charset=utf-8')
    eq_(r.status_code, 404)

    r = requests.get(nacoma_api_endpoint+'non_existing_ztuffs_here11?format=xml', auth=authed_user, verify=False)
    eq_(r.headers['content-type'], 'application/xml; charset=utf-8')
    eq_(r.status_code, 404)

    r = requests.get(nacoma_api_endpoint+'non_existing_ztuffs_here11?format=json', auth=authed_user, verify=False)
    eq_(r.headers['content-type'], 'application/json; charset=utf-8')
    eq_(r.status_code, 404)

def test_format_in_uri_overrides_accept_type():
    r = requests.get(nacoma_api_endpoint+'host?format=html', auth=authed_user, headers={ 'accept': 'application/json' }, verify=False)
    eq_(r.headers['content-type'], 'text/html; charset=utf-8')
    eq_(r.status_code, 200)

    r = requests.get(nacoma_api_endpoint+'host?format=xml', auth=authed_user, headers={ 'accept': 'application/json' },verify=False)
    eq_(r.headers['content-type'], 'application/xml; charset=utf-8')
    eq_(r.status_code, 200)

    r = requests.get(nacoma_api_endpoint+'host?format=json', auth=authed_user, headers={ 'accept': 'application/xml' },verify=False)
    eq_(r.headers['content-type'], 'application/json; charset=utf-8')
    eq_(r.status_code, 200)

def test_format_in_accept_type_overrides_default():
    r = requests.get(nacoma_api_endpoint+'host', auth=authed_user, headers={ 'accept': 'application/json' }, verify=False)
    eq_(r.headers['content-type'], 'application/json; charset=utf-8')
    eq_(r.status_code, 200)

    r = requests.get(nacoma_api_endpoint+'host', auth=authed_user, headers={ 'accept': 'application/xml' },verify=False)
    eq_(r.headers['content-type'], 'application/xml; charset=utf-8')
    eq_(r.status_code, 200)

    r = requests.get(nacoma_api_endpoint+'host', auth=authed_user, headers={ 'accept': 'text/html' },verify=False)
    eq_(r.headers['content-type'], 'text/html; charset=utf-8')
    eq_(r.status_code, 200)
